countryname_dict: A dataframe of alternative country names in many languages....

countryname_dictR Documentation

A dataframe of alternative country names in many languages. Used internally by the countryname function.

Description

A dataframe of alternative country names in many languages. Used internally by the countryname function.

Format

dataframe


countrycode documentation built on Feb. 27, 2026, 5:08 p.m.